<template>
  <div class="app-container">
    <el-row :gutter="20">
      <el-form
        :model="queryParams"
        ref="queryRef"
        :rules="rules"
        :inline="true"
        v-show="showSearch"
        :label-width="locale === 'zh' ? '90px' : '120px'"
      >
        <el-row :gutter="20">
          <el-col :span="6">
            <el-form-item :label="$t('plan.query.itemNumber')" prop="itemCode">
              <el-input
                style="width: 240px"
                v-model="queryParams.itemCode"
                :placeholder="`${$t('common.common.placeholder')}${$t(
                  'plan.query.itemNumber'
                )}`"
                clearable
                @keyup.enter="handleQuery"
              />
            </el-form-item>
          </el-col>
          <el-col :span="18" style="text-align: right">
            <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">{{
                $t("common.common.query")
              }}</el-button>
              <el-button icon="Refresh" @click="resetQuery">{{
                $t("common.common.reset")
              }}</el-button>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </el-row>
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="Refresh"
          @click="handleRefresh"
          v-hasPermi="['apsPartRouteStat:edit']"
          >{{ $t("common.common.update") }}</el-button
        >
      </el-col>
      <right-toolbar
        v-model:showSearch="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <HxlhTable
      style="width: 100%"
      :columns="columns"
      :data="planList"
      :loading="loading"
      :height="height"
      @on-checkbox="handleCheckboxChange"
      :page="page"
      @changePageNo="changePageNo"
      @changePageSize="changePageSize"
    >
      <!--       :expand-config="expandConfig"
      :subGridOptions="subGridOptions" -->
      <template #buttons="{ row }">
        <el-button
          type="primary"
          link
          @click="handleCheckView(row)"
          v-hasPermi="['aps:calendar:update']"
          >查看</el-button
        >
      </template>
    </HxlhTable>
    <el-dialog :title="title" v-model="openDialog" width="900px" append-to-body>
      <HxlhTable
        style="width: 100%"
        :columns="subGridOptions"
        :data="subList"
        :loading="loading"
        :height="heightSub"
        @on-checkbox="handleCheckboxChange"
        :page="page"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
      >
      </HxlhTable>
    </el-dialog>
  </div>
</template>

<script setup name="ApsPlatePlan">
import {
  listPlan,
  examplePlan,
  confirmPart,
} from "@/api/mainPlan/apsPlatePlan.js";
import { listProcessRoute } from "@/api/basicData/processRoute.js";
import HxlhTable from "@/components/HxlhTable/index.vue";
import { ref } from "vue";
import { getToken } from "@/utils/auth.js";
import { ElMessage } from "element-plus";
import { useI18n } from "vue-i18n"; //要在js中使用国际化
const { t, locale } = useI18n();
const { proxy } = getCurrentInstance();
// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10,
});
const {
  aps_is_suspended,
  aps_document_status,
  aps_account,
  aps_business_type,
} = proxy.useDict(
  "aps_is_suspended",
  "aps_document_status",
  "aps_account",
  "aps_business_type"
);

const planList = ref([]);
const subList = ref([]);
const loading = ref(true);
const showSearch = ref(true);
const single = ref(true);
const total = ref(0);

const height = ref(document.documentElement.clientHeight - 270 + "px;");
const heightSub = ref(document.documentElement.clientHeight - 320 + "px;");
// 表格配置
const columns = ref([]);
const openDialog = ref(false);
const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    customer: null,
    documentNumber: null,
    itemCode: null,
  },
  rules: {
    itemCode: [
      {
        required: true,
        message: `${t("common.common.placeholder")}${t(
          "plan.query.itemNumber"
        )}`,
        trigger: "blur",
      },
    ],
  },
});

const { queryParams, form, rules } = toRefs(data);
watch(
  locale,
  (newLocale) => {
    columns.value = [
      // {
      //   field: "expand",
      //   type: "expand",
      //   width: 60,
      //   align: "center",
      //   slots: { content: "expandContent" },
      // },
      // { type: "checkbox", width: 60, align: "center" },
      {
        title: t("basic.table.processRouteVersion"),
        field: "mainPartNumber",
      },
      {
        title: t("basic.table.processRouteVersion"),
        field: "businessType",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "documentNumber",
      },
      {
        title: t("basic.table.effectiveDate"),
        field: "requirementType",
      },
      {
        title: t("basic.table.expiringDate"),
        field: "documentStatus",
      },
      {
        title: t("basic.table.integrationDate"),
        field: "itemNumber",
      },
      {
        title: t("basic.table.applicableFactories"),
        field: "drawingNo",
      },
      {
        title: "操作",
        width: 100,
        fixed: "right",
        slots: { default: "buttons" },
        align: "center",
      },
    ];
  },
  { immediate: true, deep: true }
);
function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}
function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

/** 查询零件计划管理列表 */
function getList() {
  loading.value = true;
  queryParams.value.params = {};
  listPlan(queryParams.value).then((response) => {
    planList.value = response.rows;
    loading.value = false;
  });
}

/** 搜索按钮操作 */
function handleQuery() {
  proxy.$refs["queryRef"].validate((valid) => {
    if (valid) {
      getList();
    }
  });
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

function handleCheckView(row) {
  openDialog.value = true;
  listProcessRoute({ workOrderNo: row.documentNumber }).then(
      (data) => {
        subList.value = data.rows;
      })
}

// /*定义下拉二级表*/

const subGridOptions = ref([
    {
      title: "工艺路线ID",
      field: "itemNo",
      width: 150,
      align: "center",
    },
    {
      title: "工序序号",
      field: "workOrderNo",
      width: 150,
      align: "center",
    },
    {
      title: "工序名称",
      field: "processNumber",
      width: 100,
      align: "center",
    },
    {
      title: "生效日期",
      field: "processName",
      width: 150,
      align: "center",
    },
    {
      title: "失效日期",
      field: "processPlanStartDay",
      width: 200,
      align: "center",
    },
    {
      title: "集成日期",
      field: "processPlanEndDay",
      width: 200,
      align: "center",
    },
    {
      title: "适用工厂",
      field: "standardTime",
      width: 90,
      align: "center",
    },
    {
      title: "适用车间",
      field: "processOrder",
      width: 90,
      align: "center",
    },
    {
      title: "产能模型",
      field: "integrationDay",
      width: 160,
      align: "center",
    },
    {
      title: "设计产能",
      field: "integrationDay",
      width: 160,
      align: "center",
    },
  ])
// const expandConfig = ref({
//   lazy: true,
//   loadMethod({ row }) {
//     // 调用接口
//     return listProcessRoute({ workOrderNo: row.documentNumber }).then(
//       (data) => {
//         row.subList = data.rows;
//       }
//     );
//   },
// });

getList();
</script>
<style lang="css" scoped>
h4 {
  font-weight: bold;
}
</style>
